@@ -1,6 +1,6 @@
 import orjson
 import pkgutil
-from typing import Any, ClassVar
+from typing import Any, ClassVar, TextIO
 
 from BaseClasses import Tutorial
 from worlds.AutoWorld import WebWorld, World
@@ -127,6 +127,12 @@ class NineSolsWorld(World):
         apworld_manifest = orjson.loads(pkgutil.get_data(__name__, "archipelago.json").decode("utf-8"))
         slot_data["apworld_version"] = apworld_manifest["world_version"]
         # The version is stored on Worlds, so when we're ready to bump our min AP version to 0.6.4, we can do this:
-        # slot_data["apworld_version"] = self.world_version
+        # slot_data["apworld_version"] = self.world_version.to_simple_string()
         return slot_data
 
+    def write_spoiler(self, spoiler_handle: TextIO) -> None:
+        if self.jade_costs != 'vanilla':
+            spoiler_handle.write(
+                '\nRandomized Jade Costs for %s:\n\n%s' %
+                (self.multiworld.player_name[self.player], self.jade_costs)
+            )
